@@ -3,6 +3,7 @@
 from ._class2 import *
 from . import _plot_as_array
 from . import _plot_as_profile1d
+from . import _plot_as_mobile_lines
 from . import _plot_correlations
 from . import _plot_BvsA_as_distribution
 
@@ -132,6 +133,59 @@ class DataStock3(DataStock2):
             inplace=inplace,
         )
 
+    def plot_as_mobile_lines(
+        self,
+        # parameters
+        keyX=None,
+        keyY=None,
+        key_time=None,
+        key_chan=None,
+        bck=None,
+        bck_color=None,
+        ind=None,
+        aspect=None,
+        nmax=None,
+        color_dict=None,
+        dinc=None,
+        lkeys=None,
+        bstr_dict=None,
+        rotation=None,
+        # figure-specific
+        dax=None,
+        dmargin=None,
+        fs=None,
+        dleg=None,
+        connect=None,
+        inplace=None,
+    ):
+        """"""
+
+        return _plot_as_mobile_lines.plot_as_mobile_lines(
+            # parameters
+            coll=self,
+            keyX=keyX,
+            keyY=keyY,
+            key_time=key_time,
+            key_chan=key_chan,
+            bck=bck,
+            bck_color=bck_color,
+            ind=ind,
+            aspect=aspect,
+            nmax=nmax,
+            color_dict=color_dict,
+            dinc=dinc,
+            lkeys=lkeys,
+            bstr_dict=bstr_dict,
+            rotation=rotation,
+            # figure-specific
+            dax=dax,
+            dmargin=dmargin,
+            fs=fs,
+            dleg=dleg,
+            connect=connect,
+            inplace=inplace,
+        )
+
     def plot_correlations(
         self,
         # correlations
